# MONGOLIAN SPEECH CORPUS FOR TEXT-TO-SPEECH DEVELOPMENT 

Chatchawarn Hansakunbuntheung1, Ausdang Thangthai1, Nattanun Thatphithakkul1, Altangerel Chagnaa2 

1Human Language Technology Lab., National Electronics and Computer Technology Center, Thailand 2School of Information Technology, National University of Mongolia, Mongolia 

# ABSTRACT 

This paper presents a first attempt to develop Mongolian speech corpus that designed for data-driven speech synthesis in Mongolia. The aim of the speech corpus is to develop a high-quality Mongolian TTS for blinds to use with screen reader. The speech corpus contains nearly 6 hours of Mongolian female speech that is designed to cover all Mongolian phones. It well provides Cyrillic text transcription and its phonetic transcription with stress marking. It also provides context information including phone context, stressing levels, syntactic position in word, phrase and utterance for modeling speech acoustics and characteristics for speech synthesis. 

Index Terms— Speech corpus, Mongolian, Text-toSpeech Synthesis 

# 1. INTRODUCTION 

In Mongolian, the need of high quality Text-to-Speech synthesizer (TTS) is highly required for visually impaired people. A few TTS development were implemented to support the purposed in the past several years [1-5]. Due to the lack of large high-quality speech corpus designed for TTS, only few TTS systems are based on unit concatenation approach i.e. diphone-based speech synthesizers have been successfully developed [1, 2]. However, the quality of the TTS systems required more intelligibility and naturalness to be practical used in screen reader technology for visually impaired people. Within the framework of International Telecommunication Union (ITU) and Advanced Micro Devices (AMD) cooperation, ITU-AMD, aiming at human capacity building and following a Mongolia’s proposal to ITU in 2008, Mongolia has been selected as one of beneficiary countries of this ITU-AMD cooperation. According to the framework, Mongolian TTS development project is proposed as a part of the framework to provide accessibility for visually impaired people and, also, Mongolian software industrial. 

To develop a high quality Mongolian TTS for public usability, the project adopted a data-driven TTS called Hidden-Markov-Model-based TTS (HMM-based TTS or 

HTS) approach. This approach required a large welldesigned speech corpus for training acoustic models (AM) for synthesizing speech. 

The goal of this paper is to present a first attempt on a development of speech resource and tools for developing HMM-based Mongolian TTS. In this paper, firstly, an introduction to Mongolian will be described in Section 2. Section 3 will introduce a review on Mongolian resources. Then, the design of speech corpus for developing TTS is mentioned in Section 4. And, Section 5 will describe the construction of the speech corpus. After constructing the speech corpus, a preliminary analysis of the corpus will be given in Section 6. Then, an quality assessment and the issues found during the development is described in Section 7. Then, a conclusion will be described in Section 8. 

# 2. MONOLIAN LANGUAGE 

Mongolian is one of the Altaic family languages. It is spoken by nearly 8 million speakers living mainly in Mongolia, parts of China and Russia, and neighboring countries. Due to its historical and geographical background, Mongolian has several dialectal variations in its linguistic, phonetic and graphic expressions such as Khalkha, Oirat, Buryat, Khalmyc and Inner Mongolia. Furthermore, Mongolian people in different areas and historic background cannot read other’s written scripts. Hence, we focus on Khalkha (Halh) dialect that is the national language of Mongolia. Over 2.7 million people speak Mongolian throughout Mongolia. [6, 7] 

In morphology, Mongolian is a highly agglutinative language. Approximately, there are 40,000 to 50,000 words in Mongolian language. But, there are just about 10,000 root words, and, about 300 suffixes. So, it has a rich number of morphemes to build up more complex words from simple roots. [6] 

# 2.1 Mongolian writing system 

There are three written systems in Mongolian language including traditional Mongolian (Uygur Mongolian scripts), Latin, and, Cyrillic scripts as shown in Figure 1. Originally, the traditional Mongolian script is used, then, it was temporarily replaced with a Latin script for years. In 1940, Cyrillic script was introduced in Mongolia by a government decision. It gradually replaced the old Mongolian script. Nowadays, the traditional Mongolian script and Cyrillic script are used in Mongolia. But official Mongolian script is Mongolian Cyrillic script which is generally used in daily life and computer system [8, 9]. 

![](images/0c28ac0cb3bdc4d4552d1a0e02a0da5aa2c5c5d78d37589854bb8bdf366b1840.jpg)



Figure 1 Mongolian scripts 


# 2.2 Mongolian sound system 

Genuine Mongolian words use the following syllable structures: V, CV, CVC, VVC, CVCC, VCCC and CVCCC; where C is consonant and V is vowel. Mongolian has seven short vowels, seven long vowels, five diphthongs and five ‘y’-vowels. Because of variations in dialect and conflicts in theories of Mongolian phonology, there are approximately 19-23 consonants. Mongolian consonants are also categorized into hard and soft consonants. When pronouncing hard consonants the back part of the tongue is drawn back and raised. Soft consonants differ in the pronunciation from hard ones by some additional articulation [8]. Another phonological characteristic in Mongolian is stress. Usually, the long vowel also happens to be stressed, since in standard Mongolian stress falls on the first long-vowel led syllable of a word. If there is no long vowel, the word-initial syllable is stressed [6]. 

In addition, Mongolian adopts foreign-loan words especially from Old Turkic, Sanskrit, Tibetan, Tungusic and Chinese, Russian, Chinese and English [6]. In consequence of the mentioned issues, extra phones and syllable structures occurs additionally, and, are used in present Mongolian. 

# 3. REVIEW ON MONGOLIAN RESOURCES 

# 3.1 Mongolian text resource 

A large Mongolian text corpus of 5 million words is collected at National University of Mongolia [10, 11]. The content of the corpus is mostly from domains like daily online or printed newspapers, literature, and laws. The text corpus is already cleaned and tagged semi-automatically by spell checker and parsing tools. 

# 3.2 Mongolian speech resource 

Existing Mongolian speech corpora have been collected for various purposes. A Multi-dialectal speech corpus of Mongolia (MDSCM) attempted to collect and to preserve variation of Mongolian text and speech dialects. In this corpus, it classify the Mongolian dialects into three fundamental groups, i.e., Khalha, Chhar, and Oirat, which are used widely by large population [7, 12]. However, the specification of MDSCM is not designed to consider phone variation and coverage for speech synthesis implementation. 

Another existing speech corpus is designed for automatic speech recognition (ASR). Because of its goal for ASR, it collected speech data of multi-speakers. Lists of 10 words were recorded repeatedly 10 times by 10 speakers. In total, 80 speakers’ speech data were collected and consists of 60,000 wave files [13]. 

# 4. CORPUS DESIGN 

As mentioned above, there is no available large speech resource designed for speech synthesis. This section will describe the design of the proposed speech corpus. 

# 4.1 Practical Mongolian Phonetic transcription 

As mentioned in Section 2.2, there are variations and some conflicts on the theories of Mongolian language and phonology. Thus, this work focuses on the practical design and usage of phonetic transcription based on the theories by the linguists and researchers at NUM. The design sticks to official Mongolian dialect, Khalkha. By gathering all genuine Mongolian and loan phones, a summarization of Mongolian consonant and vowel phones are presented in Table 1 and, Table 2 respectively. In Table 1, the phones noted by lowercase represent soft sound and the uppercase ones represent hard sounds. In Table 2, the phones without colon “:” represent short vowels while the phones with colon “:” represent long vowels, and, the phones suffixed by “y” represent diphthongs. 

Concerning syllable structure in real usage, we found that some foreign-loan words have more complex syllable structure than described in Section 2.2 i.e. superheavy syllable structure of six phones or more. So, all complex syllable structures will be considered during phonetic transcription and further analysis. 

To transcribe phone labels rapidly, a grapheme-tophoneme (G2P) converter was developed to assist transcribing phone labels and stress levels. Fortunately, most of Mongolian G2P conversion is direct mapping that can cover by rules. Words that were not covered by rules were added into an “exception” dictionary. We found that most exception words were foreign-loan words that used extra phones from the genuine Mongolian phone set. 

In real speech, an interesting feature of Mongolian speech is that vowels are less stable than consonants. Short phonemic vowels in the initial syllable can be devoiced and even deleted completely in fast speech [14]. To reduce the difficulties in phonetic transcription and to increase the accuracy of phonetic transcription using the G2P tool, we asked a speaker to speak with clear voice and formal speech pronunciation while preserving natural speaking style. 

# 4.2 Text preparation 

To efficiently imitate a speaker’s voice characteristics, we considered the following criteria for selecting a set of text for training acoustic models: 

An adequate amount of speech material per speaker Phone balancing that cover all Mongolian sounds. 

Thus, the 5-million text data described in Section 3.1 is adopted for selecting phone balanced text set. As the results, the total 1500 sentences that cover all Mongolian sounds were selected. Figure 2 shows partial samples of the 1500- sentence set. 

# 5. SPEECH CORPUS CONSTRUCTION 

# 5.1 Speech segmentation and labeling 

To prepare speech segments for training Mongolian acoustic models, we performed HMM-based force-alignment using bootstrapped acoustic models to align boundaries of Mongolian phonetic transcription with the recorded speech. In the actual recorded speech data, we found alignment errors caused by short pauses insertion occurred in the mid of sentences. So, tagging short pauses in the phonetic transcription was performed manually to improve the alignment accuracy. Approximately, 14,581 short-pause tags were inserted as shown in Figure 3. Then, the force alignment was re-applied with the short-pause information on the speech data. The re-aligned phone labeling gave improved result. 


Table 1 Mongolian consonant phoneme 




<table><tr><td rowspan=1 colspan=1>IPA</td><td rowspan=1 colspan=1>Phonemesymbols</td><td rowspan=1 colspan=1>Samplesound</td><td rowspan=1 colspan=1>IPA</td><td rowspan=1 colspan=1>Phoneme</td><td rowspan=1 colspan=1>Samplesound</td></tr><tr><td rowspan=1 colspan=1>ph</td><td rowspan=1 colspan=1>b</td><td rowspan=1 colspan=1>B</td><td rowspan=1 colspan=1>pjh</td><td rowspan=1 colspan=1>B</td><td rowspan=1 colspan=1>Bь</td></tr><tr><td rowspan=1 colspan=1>ts</td><td rowspan=1 colspan=1>с</td><td rowspan=1 colspan=1>Ц</td><td rowspan=1 colspan=1>g</td><td rowspan=1 colspan=1>C</td><td rowspan=1 colspan=1>Гь</td></tr><tr><td rowspan=1 colspan=1>th</td><td rowspan=1 colspan=1>d</td><td rowspan=1 colspan=1>D</td><td rowspan=1 colspan=1>th</td><td rowspan=1 colspan=1>D</td><td rowspan=1 colspan=1>Дь</td></tr><tr><td rowspan=1 colspan=1>g</td><td rowspan=1 colspan=1>g</td><td rowspan=1 colspan=1>Γ</td><td rowspan=1 colspan=1>G</td><td rowspan=1 colspan=1>G</td><td rowspan=1 colspan=1>Га</td></tr><tr><td rowspan=1 colspan=1>kh</td><td rowspan=1 colspan=1>k</td><td rowspan=1 colspan=1>K</td><td rowspan=1 colspan=1>kjh</td><td rowspan=1 colspan=1>K</td><td rowspan=1 colspan=1>Кь</td></tr><tr><td rowspan=1 colspan=1>\3</td><td rowspan=1 colspan=1>1</td><td rowspan=1 colspan=1>Л</td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>L</td><td rowspan=1 colspan=1>Ль</td></tr><tr><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>m</td><td rowspan=1 colspan=1>M</td><td rowspan=1 colspan=1>mi</td><td rowspan=1 colspan=1>M</td><td rowspan=1 colspan=1>Мь</td></tr><tr><td rowspan=1 colspan=1>n</td><td rowspan=1 colspan=1>n</td><td rowspan=1 colspan=1>H</td><td rowspan=1 colspan=1>nj</td><td rowspan=1 colspan=1>N</td><td rowspan=1 colspan=1>Нь</td></tr><tr><td rowspan=1 colspan=1>р</td><td rowspan=1 colspan=1>p</td><td rowspan=1 colspan=1>Π</td><td rowspan=1 colspan=1>pj</td><td rowspan=1 colspan=1>P</td><td rowspan=1 colspan=1>Пь</td></tr><tr><td rowspan=1 colspan=1>r</td><td rowspan=1 colspan=1>r</td><td rowspan=1 colspan=1>P</td><td rowspan=1 colspan=1>rj</td><td rowspan=1 colspan=1>R</td><td rowspan=1 colspan=1>Рь</td></tr><tr><td rowspan=1 colspan=1>S</td><td rowspan=1 colspan=1>S</td><td rowspan=1 colspan=1>C</td><td rowspan=1 colspan=1>L</td><td rowspan=1 colspan=1>S</td><td rowspan=1 colspan=1>Ш</td></tr><tr><td rowspan=1 colspan=1>t</td><td rowspan=1 colspan=1>t</td><td rowspan=1 colspan=1>T</td><td rowspan=1 colspan=1>ti</td><td rowspan=1 colspan=1>T</td><td rowspan=1 colspan=1>Ть</td></tr><tr><td rowspan=1 colspan=1>W</td><td rowspan=1 colspan=1>V</td><td rowspan=1 colspan=1>B</td><td rowspan=1 colspan=1>wj</td><td rowspan=1 colspan=1>V</td><td rowspan=1 colspan=1>Вь</td></tr><tr><td rowspan=1 colspan=1>X</td><td rowspan=1 colspan=1>X</td><td rowspan=1 colspan=1>X</td><td rowspan=1 colspan=1>xj</td><td rowspan=1 colspan=1>X</td><td rowspan=1 colspan=1>Хь</td></tr><tr><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>f</td><td rowspan=1 colspan=1>Ф</td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td></tr><tr><td rowspan=1 colspan=1>h</td><td rowspan=1 colspan=1>h</td><td rowspan=1 colspan=1>Ψ</td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td></tr><tr><td rowspan=1 colspan=1>j</td><td rowspan=1 colspan=1>j</td><td rowspan=1 colspan=1>Я,Ё,Ю</td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td></tr><tr><td rowspan=1 colspan=1>1</td><td rowspan=1 colspan=1>ng</td><td rowspan=1 colspan=1>Hr</td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td></tr><tr><td rowspan=1 colspan=1>W</td><td rowspan=1 colspan=1>W</td><td rowspan=1 colspan=1>Ж</td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td></tr><tr><td rowspan=1 colspan=1>tsh</td><td rowspan=1 colspan=1>Z</td><td rowspan=1 colspan=1>3</td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td></tr></table>




Table 2 Mongolian vowel phoneme 




<table><tr><td rowspan=1 colspan=1>IPA</td><td rowspan=1 colspan=1>Phoneticsymbols</td><td rowspan=1 colspan=1>Samplesound</td><td rowspan=1 colspan=1>IPA</td><td rowspan=1 colspan=1>Phoneticsymbols</td><td rowspan=1 colspan=1>Samplesound</td></tr><tr><td rowspan=1 colspan=1>a</td><td rowspan=1 colspan=1>a</td><td rowspan=1 colspan=1>а</td><td rowspan=1 colspan=1>a:</td><td rowspan=1 colspan=1>a:</td><td rowspan=1 colspan=1>aa</td></tr><tr><td rowspan=1 colspan=1>е</td><td rowspan=1 colspan=1>е</td><td rowspan=1 colspan=1>э</td><td rowspan=1 colspan=1>e:</td><td rowspan=1 colspan=1>e:</td><td rowspan=1 colspan=1>ээ</td></tr><tr><td rowspan=1 colspan=1>I</td><td rowspan=1 colspan=1>i</td><td rowspan=1 colspan=1>И</td><td rowspan=1 colspan=1>i:</td><td rowspan=1 colspan=1>i:</td><td rowspan=1 colspan=1>ий</td></tr><tr><td rowspan=1 colspan=1>э</td><td rowspan=1 colspan=1>о</td><td rowspan=1 colspan=1>о</td><td rowspan=1 colspan=1>3:</td><td rowspan=1 colspan=1>0:</td><td rowspan=1 colspan=1>00</td></tr><tr><td rowspan=1 colspan=1>U</td><td rowspan=1 colspan=1>u</td><td rowspan=1 colspan=1>y</td><td rowspan=1 colspan=1>u:</td><td rowspan=1 colspan=1>u:</td><td rowspan=1 colspan=1>y</td></tr><tr><td rowspan=1 colspan=1>о</td><td rowspan=1 colspan=1>@</td><td rowspan=1 colspan=1>θ</td><td rowspan=1 colspan=1>0:</td><td rowspan=1 colspan=1>@:</td><td rowspan=1 colspan=1>θ</td></tr><tr><td rowspan=1 colspan=1>U</td><td rowspan=1 colspan=1>л</td><td rowspan=1 colspan=1>Y</td><td rowspan=1 colspan=1>U:</td><td rowspan=1 colspan=1>^:</td><td rowspan=1 colspan=1>Y</td></tr><tr><td rowspan=1 colspan=1>і</td><td rowspan=1 colspan=1>y</td><td rowspan=1 colspan=1>Ы</td><td rowspan=1 colspan=1>ay</td><td rowspan=1 colspan=1>ay</td><td rowspan=1 colspan=1>ай</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>эу</td><td rowspan=1 colspan=1>оу</td><td rowspan=1 colspan=1>ой</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>uy</td><td rowspan=1 colspan=1>uy</td><td rowspan=1 colspan=1>уй</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>еу</td><td rowspan=1 colspan=1>ey</td><td rowspan=1 colspan=1>эй</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>оу</td><td rowspan=1 colspan=1>^y</td><td rowspan=1 colspan=1>үй</td></tr></table>



![](images/d8ecdaec35ffc3e031a03f3d62ddb8fc0a5854dbfd1f58cf0e72453e64a760e3.jpg)



Figure 2 Samples of phonetic transcription of the 1500-sentence phone-balanced set 


![](images/7a58ecad478fa55dfd66808728c58a712ed227db088f6f2876b16b77ba49ee13.jpg)



Figure 3 Samples of speech transcription with short-pause insertion 



Table 3 Context linguistic information 




<table><tr><td rowspan=1 colspan=1>Level</td><td rowspan=1 colspan=1>Feature</td><td rowspan=1 colspan=1>Description</td><td rowspan=1 colspan=1>Value</td></tr><tr><td rowspan=1 colspan=1>Phoneme</td><td rowspan=1 colspan=1>Ph-2, Ph-1, Ph, Ph+1, Ph+2</td><td rowspan=1 colspan=1>Five context phonemes (two preceding, twosuceeding, and, current phonemes)</td><td rowspan=1 colspan=1>Phoneme</td></tr><tr><td rowspan=1 colspan=1>Syllable</td><td rowspan=1 colspan=1>T-2, T-1, T, T+1, T+2</td><td rowspan=1 colspan=1>Five context stressing (stressing of two preceding,two suceeding, and, current syllables)</td><td rowspan=1 colspan=1>Stressed, Unstressed</td></tr><tr><td rowspan=1 colspan=1>Word</td><td rowspan=1 colspan=1>Pos_Syl_Wrd</td><td rowspan=1 colspan=1>Syllable position in a word</td><td rowspan=1 colspan=1>Single, Begin, Center, End</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>NSyl_Wrd</td><td rowspan=1 colspan=1>Total number of syllables in a word</td><td rowspan=1 colspan=1>Integer</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>NCurrSyl_Wrd</td><td rowspan=1 colspan=1>Position index of current syllable in a word</td><td rowspan=1 colspan=1>Integer</td></tr><tr><td rowspan=1 colspan=1>Phrase</td><td rowspan=1 colspan=1>Pos_Syl_PB</td><td rowspan=1 colspan=1>Syllable position in current phrase</td><td rowspan=1 colspan=1>Single, Begin, Center, End</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>NSyl_PB</td><td rowspan=1 colspan=1>Total number of syllables in current phrase</td><td rowspan=1 colspan=1>Integer</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>NCurrSyl_PB</td><td rowspan=1 colspan=1>Position index of current syllable in current phrase</td><td rowspan=1 colspan=1>Integer</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>Pos_Wrd_PB</td><td rowspan=1 colspan=1>Word position in current phrase</td><td rowspan=1 colspan=1>Single, Begin, Center, End</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>NWrd_PB</td><td rowspan=1 colspan=1>Total number of words in current phrase</td><td rowspan=1 colspan=1>Integer</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>NCurrWrd_PB</td><td rowspan=1 colspan=1>Position index of current word in current phrase</td><td rowspan=1 colspan=1>Integer</td></tr><tr><td rowspan=1 colspan=1>Utterance</td><td rowspan=1 colspan=1>Pos_Syl_Utt</td><td rowspan=1 colspan=1>Syllable position in current utterance</td><td rowspan=1 colspan=1>Single, Begin, Center, End</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>Pos_Wrd_Utt</td><td rowspan=1 colspan=1>Word position in current utterance</td><td rowspan=1 colspan=1>Single, Begin, Center, End</td></tr><tr><td rowspan=1 colspan=1></td><td rowspan=1 colspan=1>Pos_Phr_Utt</td><td rowspan=1 colspan=1>Phrase position in th current utterance</td><td rowspan=1 colspan=1>Single, Begin, Center, End</td></tr></table>



# 5.2 Speech recording specification 

The speech corpus construction is designed to get high quality speech material for speech synthesis. In this recording, we assigned a native voice talent on Mongolian pronunciation as a speaker. The speaker is a Mongolian female linguist. The recording was done in a sound-proof audio studio with high-quality equipments. 

In total, approximate 6 hours of clean speech of the designed 1500 sentences were recorded at $4 8 ~ \mathrm { k H z }$ sampling rate with 16 bits per sample and stored in lossless noncompression wave format. The signal-to-noise ratio (SNR) of the recorded speech is approximately in range of 30-40 dB. 

# 5.3 Context linguistic labeling 

However, only local phone information is not sufficient to train accurate acoustic models. We also extracted various kinds of context information for training the HMM-based acoustic models. To construct the context linguistic labels, a set of five linguistic levels, including phone, syllable, word, phrase, and, utterance levels as shown in Table 3, are extracted from the 1500-sentence text set. To preserve context information, five-phoneme-width window is used to extract the phone and stressing context information. 

# 6. CORPUS ANALYSIS 

The general specification of the corpus is shown in Table 4. The output corpus is nearly 6 hours covering approximate 10,000 Mongolian unique words. In Figure 4 presenting the histogram of syllable length, we found a small amount of superheavy syllables that represent foreign-loan word in Mongolian. However, the average syllable length of Mongolian syllables as shown in Table 4 is 2.54 phones per syllable that is heavy syllable type. The histogram of Mongolian phone duration as shown in Figure 5 presents a homogeneous distribution with average of $1 1 6 . 3 ~ \mathrm { ~ m s }$ per phone. 

We checked the phoneme coverage of the speech corpus. Figure 6 shows the distribution of Mongolian phoneme found in the corpus. By observing the frequency of phones, most soft phones are located on the left side of the distribution that showing high frequency of occurrences. In contrast, most of hard phones locating on the low-frequency side rarely occur in real speech comparing with the soft ones. When considering the frequency of vowels, we noticed that the distribution of vowel frequencies was arranged in this order: short vowels (a, e, i, ɔ, u), long vowels (a:, e:, i:, ɔ:, u:, ʊ:), and, diphthongs (ay, ey, ɔy, ʊy, uy) with some overlaps. 


Table 4 Speech corpus specification 




<table><tr><td rowspan=1 colspan=1>Overall duration</td><td rowspan=1 colspan=1>5 hr 52 min</td></tr><tr><td rowspan=1 colspan=1>Average sentence duration</td><td rowspan=1 colspan=1>14.1 s</td></tr><tr><td rowspan=1 colspan=1>Average phrase duration</td><td rowspan=1 colspan=1>1.45 s</td></tr><tr><td rowspan=1 colspan=1>Average syllable duration</td><td rowspan=1 colspan=1>0.295 ms</td></tr><tr><td rowspan=1 colspan=1>Average phone duration</td><td rowspan=1 colspan=1>116.3 ms</td></tr><tr><td rowspan=1 colspan=1>No. Sentences</td><td rowspan=1 colspan=1>1,500</td></tr><tr><td rowspan=1 colspan=1>No. phrases</td><td rowspan=1 colspan=1>14,581</td></tr><tr><td rowspan=1 colspan=1>No. Words</td><td rowspan=1 colspan=1>27,270</td></tr><tr><td rowspan=1 colspan=1>No. of unique words</td><td rowspan=1 colspan=1>9,401</td></tr><tr><td rowspan=1 colspan=1>No. Syllable</td><td rowspan=1 colspan=1>53,610</td></tr><tr><td rowspan=1 colspan=1>No. of Stressed syllables</td><td rowspan=1 colspan=1>26,278</td></tr><tr><td rowspan=1 colspan=1>No. of unstressed syllables</td><td rowspan=1 colspan=1>27,332</td></tr><tr><td rowspan=1 colspan=1>Total number of phones</td><td rowspan=1 colspan=1>136,083</td></tr><tr><td rowspan=1 colspan=1>Average number of phones/syllable</td><td rowspan=1 colspan=1>2.54</td></tr><tr><td rowspan=1 colspan=1>No. of unique phones</td><td rowspan=1 colspan=1>53</td></tr></table>



![](images/4a2f9695efc79c79e872574869a303f232462d515d3476cf73e723188f6dd59b.jpg)



Figure 4 Histogram of Mongolian syllable length 


![](images/f0ad055d7f524f29f6cb8419ae39c98406fdf3ff2c5a081e56bf07ad7d805438.jpg)



Figure 5 Histogram of Mongolian phone duration 


![](images/077e8cf20edfa556e73e0f36fdbbbf688fbb2e043788cf5bedde2face8bd2a97.jpg)



Figure 6 Phone distribution 


# 7. EVALUATION AND FOUND ISSUES 

Using the designed speech corpus, a set of HMM-based acoustic models for a Mongolian TTS prototype has been trained to generate a set of twenty-five synthesized speech samples for evaluation. We tried to optimize the acoustic models to get the best quality under the time limitation of the project conditions. We set up a listening test based on 5- scale Mean Opinion Score (MOS) with fifteen Mongolian raters. All the raters were asked to listen to each speech sample together, and, rated a MOS for each sample. Due to the limitation of the facility at the evaluating place, only a pair of general computer speakers was available for playing the speech samples. The evaluation resulted an average MOS of 3.34 that was just slightly higher than fair quality level. After the listening test, the rater re-listen the speech sample on their headphones. They commented that the quality of the speakers used for evaluation was too low and made them evaluate the quality of the speech samples lower than they should rate. Another suggestion that explained why the MOS was not high is that it was caused by strange pronunciation of foreign-load words generated by the G2P and it disturbed the overall quality of the speech samples they listen to. 

In the development viewpoint, the main issue on developing Mongolian speech corpus is the difficulty of G2P conversion for foreign-loan words that produce a number of pronunciation exceptions. This issue will cause problems when adding new text into the corpus. And, it will cause the pronunciation mistakes when using in TTS. Another issue is the number of some phones seems to be too small for training acoustic models. Additional speech data should be acquired more in the future. 

# 8. CONCLUSION 

This work presented a first attempt to develop Mongolian speech corpus that designed for data-driven speech synthesis. The speech corpus is designed to cover all Mongolian phones. It well provided phonetic transcription with stress marking and also context information for further modeling speech acoustics and characteristics for speech synthesis. In addition, there are two issues to be deal with in the future including G2P conversion issue on foreign words and inadequate number of some phones for well training acoustic models. Conclusively, the Mongolian speech corpus is a well startup for implementing a data-driven Mongolian TTS. It also needs further development on the issues in future works. 

# 9. ACKNOWNLEDGEMENT 

This work is supported by ITU-AMD and the Australian Government particularly the Department of Communications, Broadband and the Digital Economy (DBCDE). It is a collaborative project of the following partners including 1) National IT Park (NITP) in Mongolia 2) School of Information Technology (SIT), National University of Mongolia (NUM) in Mongolia, and, 3) National Electronics and Computer Technology Center (NECTEC) in Thailand. This work is also supported by Mongolian National Federation of the Blind (MNFB) in providing informative requirements and the evaluation of real blind users. 

# 10. REFERENCES 

[1] B. Batchuluun, D. Batchuluun, and, G. Gombosuren, “Mongolian text to speech conversion tool”, Project Ref.No: 0501A2_L13, Interim report, InfoCon Co., Ltd, Mongolia, http://www.infocon.mn/tts/, 2006.   
[2] M. Davaatsagaan, and, K. Paliwal, “Diphone-Based Concatenative Speech Synthesis System for Mongolian”, Int’l MultiConference of Engineers and Computer Scientists (IMECS) 2008, Vol I, 2008.   
[3] B. Sukhbaatar, and, D. Munkhtuya, “A New Approach For The Mongolian Text-To-Speech Conversion”, Proc. Int’l Conference on Electronics, Information, and Communication (ICEIC 2006), Vol. 2, pp.303 – 306, 2006.   
[4] B. Otgonbayar, “Study of all necessary parameters and characteristics of Mongolian speech synthesis system and establishing functional model for Mongolian spoken language”, Ph.D. thesis, Mongolian University of Science and Technology, Mongolia, 1996.   
[5] O. Bat-Enkh, “Investigation on New Approach to Build Speech Synthesis System for Mongolian Language”, Ph.D. thesis, Mongolian University of Science and Technology, Mongolia, 2001. [6] D. Bayanduuren, “Mongolian Speech Recognition”, PAN localization Project Phase II , Mongolia, 2007.   
[7] I. Dawa, Husal, L. Yue, Y. Y. Ming, Uulang, B. S. Cheng, Batsaihan, Y.Arai, M. Mitsunaga, H. Isahara, and, S. Nakamura, “Multilingual Text – Speech Corpus of Mongolian”, Int’l Symposium on Chinese Spoken Language Processing (ISCSLP 2006), 2006.   
[8] A. Altangerel, and, B. Damdinsuren, “Research Report on ASR Development for Mongolian”, PAN localization Project Phase II , 2009.   
[9] Ts. Damdinsuren, “Mongol shine usgiin tovch durem”, Ulaanbaatar, 1946.   
[10] P. Jaimai, and, A. Chagnaa, “Language Resources for Mongolian”, Human Language Technology for Development (HLTD 2011), pp. 56-61, 2011.   
[11] P. Jaimai, and, O. Chimeddorj, “Corpus Building for Mongolian Language”, 6th Workshop on Asian Language Resources, 2008.   
[12] I. Dawa, S. Okawa, and K. Shirai, “Design and assessment of Mongolian dialectal speech input sysytem,” Proc.   
EALREW99, Taipei, pp. 45-48, 1999.   
[13] A. Ayush, and, D. Bayanduren, “Mongolian Speech corpus”, PAN localization Project Phase II, 2009.   
[14] A. M. Karlsson, and, J. Svantesson, “What happens to consonant clusters in Mongolian speech?”, Rossijskaja akademija nauk / Russian Academy of Science, 2007. 